@@ -7,6 +7,8 @@ class GenerationSettingsLoader:
         settings_data: GenerationSettings = GenerationSettings()
         if settings_file["data"]["settings_file"]["path"] is not None:
             settings_data.data_settings_file_path = settings_file["data"]["settings_file"]["path"]
+        else:
+            settings_data.data_settings_file_path = "./settings.yaml"
         settings_data.data_input_path = settings_file["data"]["input"]["path"]
         settings_data.data_input_separator = settings_file["data"]["input"]["separator"]
         settings_data.data_extraction_function_path = settings_file["data"]['extraction']['function']['path']
